@@ -9,13 +9,13 @@
 
 #include <QQmlNetworkAccessManagerFactory>
 
-namespace KDeclarative {
-
+namespace KDeclarative
+{
 class KIOAccessManagerFactory : public QQmlNetworkAccessManagerFactory
 {
 public:
     KIOAccessManagerFactory();
-    ~KIOAccessManagerFactory();
+    ~KIOAccessManagerFactory() override;
     QNetworkAccessManager *create(QObject *parent) override;
 };
 
