@@ -7,7 +7,7 @@
 #include "imagetexturescache.h"
 #include <QSGTexture>
 
-typedef QHash<qint64, QHash<QWindow*, QWeakPointer<QSGTexture> > > TexturesCache;
+typedef QHash<qint64, QHash<QWindow *, QWeakPointer<QSGTexture>>> TexturesCache;
 
 class ImageTexturesCachePrivate
 {
@@ -30,20 +30,21 @@ QSharedPointer<QSGTexture> ImageTexturesCache::loadTexture(QQuickWindow *window,
     QSharedPointer<QSGTexture> texture = d->cache.value(id).value(window).toStrongRef();
 
     if (!texture) {
-        auto cleanAndDelete = [this, window, id](QSGTexture* texture) {
-            QHash<QWindow*, QWeakPointer<QSGTexture> >& textures = (d->cache)[id];
+        auto cleanAndDelete = [this, window, id](QSGTexture *texture) {
+            QHash<QWindow *, QWeakPointer<QSGTexture>> &textures = (d->cache)[id];
             textures.remove(window);
-            if (textures.isEmpty())
+            if (textures.isEmpty()) {
                 d->cache.remove(id);
+            }
             delete texture;
         };
         texture = QSharedPointer<QSGTexture>(window->createTextureFromImage(image, options), cleanAndDelete);
         (d->cache)[id][window] = texture.toWeakRef();
     }
 
-    //if we have a cache in an atlas but our request cannot use an atlassed texture
-    //create a new texture and use that
-    //don't use removedFromAtlas() as that requires keeping a reference to the non atlased version
+    // if we have a cache in an atlas but our request cannot use an atlassed texture
+    // create a new texture and use that
+    // don't use removedFromAtlas() as that requires keeping a reference to the non atlased version
     if (!(options & QQuickWindow::TextureCanUseAtlas) && texture->isAtlasTexture()) {
         texture = QSharedPointer<QSGTexture>(window->createTextureFromImage(image, options));
     }
